@@ -92,8 +92,8 @@ setMethod("matrixClass", "DelayedArray", function(x) "DelayedMatrix")
 .msg_for_old_internals <- function(object, pkgversion)
 {
     paste0(class(object), " object uses internal representation ",
-           "from DelayedArray\n  ", pkgversion, " and cannot be displayed ",
-           "or used. Please update it with:\n\n",
+           "from DelayedArray\n  ", pkgversion, " and cannot be ",
+           "displayed or used. Please update it with:\n\n",
            "      object <- updateObject(object, verbose=TRUE)\n\n",
            "  and re-serialize it.")
 }
@@ -114,15 +114,15 @@ setMethod("matrixClass", "DelayedArray", function(x) "DelayedMatrix")
 {
     pkgversion <- .get_DelayedArray_pkgversion(x)
     if (pkgversion != "current")
-        return(paste0("\n  ", .msg_for_old_internals(x, pkgversion)))
+        return(.msg_for_old_internals(x, pkgversion))
 #    seed_dim <- dim(x@seed)
 #    seed_ndim <- length(seed_dim)
 #    ## In the context of validObject(), 'class(x)' is always "DelayedArray"
 #    ## and not the real class of 'x', which seems to be a bug in validObject().
 #    ## This prevents us from doing the check below.
 #    if (seed_ndim == 2L && !is(x, matrixClass(x)))
-#        return(wmsg2("'x' has 2 dimensions but is not a ",
-#                     matrixClass(x), " derivative"))
+#        return(paste0("'x' has 2 dimensions but is not a ",
+#                      matrixClass(x), " derivative"))
     TRUE
 }
 
@@ -133,7 +133,7 @@ setValidity2("DelayedArray", .validate_DelayedArray)
 .validate_DelayedMatrix <- function(x)
 {
     if (length(dim(x)) != 2L)
-        return(wmsg2("'x' must have exactly 2 dimensions"))
+        return("'x' must have exactly 2 dimensions")
     TRUE
 }
 
@@ -360,7 +360,7 @@ setClass("DelayedArray1",
 
 .updateObject_DelayedArray <- function(object, ..., verbose=FALSE)
 {
-    object@seed <- updateObject(object@seed, verbose=verbose)
+    object@seed <- updateObject(object@seed, ..., verbose=verbose)
 
     internals_version <- .get_DelayedArray_internals_version(object)
     pkgversion <- .get_pkgversion_from_internals_version(internals_version)
@@ -487,118 +487,6 @@ stash_DelayedAbind <- function(x, objects, along)
 }
 
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### nseed()
-###
-### Return the number of leaves in the tree of DelayedOp nodes represented
-### by 'x'. Note that nseed(x) == 1 means that the tree is linear.
-###
-
-setGeneric("nseed", function(x) standardGeneric("nseed"))
-
-setMethod("nseed", "ANY",
-    function(x)
-    {
-        if (is(x, "DelayedUnaryOp"))
-            return(nseed(x@seed))
-        if (is(x, "DelayedNaryOp"))
-            x <- x@seeds
-        if (is.list(x)) {
-            ans <- sum(vapply(x, nseed, integer(1), USE.NAMES=FALSE))
-            return(ans)
-        }
-        return(1L)
-    }
-)
-
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### seed() getter/setter
-###
-### If nseed(x) == 1 (i.e. if 'x' is a linear tree) then the seed() getter
-### and setter MUST work on 'x'.
-###
-
-setGeneric("seed", function(x) standardGeneric("seed"))
-
-setMethod("seed", "DelayedOp",
-    function(x)
-    {
-        if (is(x, "DelayedNaryOp")) {
-            ## Tree is not linear.
-            stop(wmsg("seed() ", IS_NOT_SUPOORTED_IF_MULTIPLE_SEEDS))
-        }
-        x1 <- x@seed
-        if (!is(x1, "DelayedOp"))
-            return(x1)  # found the leaf seed
-        x <- x1
-        callGeneric()  # recursive call
-    }
-)
-
-setGeneric("seed<-", signature="x",
-    function(x, ..., value) standardGeneric("seed<-")
-)
-
-.normalize_seed_replacement_value <- function(value, x_seed)
-{
-    if (!is(value, class(x_seed)))
-        stop(wmsg("supplied seed must be a ", class(x_seed), " object"))
-    if (!identical(dim(value), dim(x_seed)))
-        stop(wmsg("supplied seed must have the same dimensions ",
-                  "as current seed"))
-    if (!identical(dimnames(value), dimnames(x_seed)))
-        stop(wmsg("supplied seed must have the same dimnames ",
-                  "as current seed"))
-    value
-}
-
-setReplaceMethod("seed", "DelayedOp",
-    function(x, value)
-    {
-        if (is(x, "DelayedNaryOp")) {
-            ## Tree is not linear.
-            stop(wmsg("the seed() setter ", IS_NOT_SUPOORTED_IF_MULTIPLE_SEEDS))
-        }
-        x1 <- x@seed
-        if (!is(x1, "DelayedOp")) {
-            ## Replace the leaf seed.
-            x@seed <- .normalize_seed_replacement_value(value, x1)
-            return(x)
-        }
-        seed(x1) <- value  # recursive call
-        x@seed <- x1
-        x
-    }
-)
-
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### path() getter/setter
-###
-
-### The path of a DelayedArray object is the path of its leaf seed. So path()
-### will work on a DelayedArray object only if it works on its leaf seed.
-### For example it will work if its leaf seed is an on-disk object (e.g. an
-### HDF5ArraySeed object) but not if it's an in-memory object (e.g. an
-### ordinary array or RleArraySeed object).
-setMethod("path", "DelayedArray",
-    function(object, ...) path(seed(object), ...)
-)
-
-### The path() setter will work on a DelayedArray object only if it works on
-### its leaf seed. For example it will work if its leaf seed is an on-disk
-### object (e.g. an HDF5ArraySeed object) but not if it's an in-memory object
-### (e.g. an ordinary array or RleArraySeed object).
-setReplaceMethod("path", "DelayedArray",
-    function(object, ..., value)
-    {
-        path(seed(object), ...) <- value
-        object
-    }
-)
-
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### aperm()
 ###
