@@ -18,6 +18,56 @@ seq2 <- function(to, by)
 }
 
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Greatest common divisor and least common multiple of 2 integers
+###
+### Currently not used.
+###
+### TODO: Maybe should go to S4Vectors (and be implemented in C).
+###
+
+if (FALSE) {  # ------------ BEGIN DISABLED CODE ------------
+
+### Greatest common divisor of 2 integers.
+### Can be about 10x faster than this recursive (and vectorized) solution
+### from SO:
+###   https://stackoverflow.com/questions/21502181/finding-the-gcd-without-looping-r
+### Also check user input and handle edge cases.
+GCD <- function(x, y)
+{
+    stopifnot(isSingleNumber(x), isSingleNumber(y))
+    if (!is.integer(x))
+        x <- as.integer(x)
+    if (!is.integer(y))
+        y <- as.integer(y)
+    if (y == 0L) {
+        if (x == 0L)
+            return(NA_integer_)
+        return(x)
+    }
+    while (TRUE) {
+        r <- x %% y
+        if (r == 0L)
+            return(y)
+        x <- y
+        y <- r
+    }
+}
+
+### Least common multiple of 2 integers.
+LCM <- function(x, y)
+{
+    stopifnot(isSingleNumber(x), isSingleNumber(y))
+    if (!is.integer(x))
+        x <- as.integer(x)
+    if (!is.integer(y))
+        y <- as.integer(y)
+    gcd <- GCD(x, y)
+    (x %/% gcd) * y  # could overflow
+}
+}             # ------------- END DISABLED CODE -------------
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### 2 wrappers to dim<- and dimnames<- that try to avoid unnecessary copies
 ### of 'x'
@@ -98,24 +148,17 @@ combine_array_objects <- function(objects)
 ### Used in validity methods
 ###
 
-### A modified version of S4Vectors::wmsg() that is better suited for use
-### by validity methods.
-### TODO: Put this in S4Vectors next to wmsg(). Would probably need a better
-### name.
-wmsg2 <- function(...)
-    paste0("\n    ",
-           paste0(strwrap(paste0(c(...), collapse="")), collapse="\n    "))
-
+### NOT exported but used in the HDF5Array package!
 validate_dim_slot <- function(x, slotname="dim")
 {
     x_dim <- slot(x, slotname)
     if (!is.integer(x_dim))
-        return(wmsg2(sprintf("'%s' slot must be an integer vector", slotname)))
+        return(paste0("'", slotname, "' slot must be an integer vector"))
     if (length(x_dim) == 0L)
-        return(wmsg2(sprintf("'%s' slot cannot be empty", slotname)))
+        return(paste0("'", slotname, "' slot cannot be empty"))
     if (S4Vectors:::anyMissingOrOutside(x_dim, 0L))
-        return(wmsg2(sprintf("'%s' slot cannot contain negative or NA values",
-                             slotname)))
+        return(paste0("'", slotname, "' slot cannot contain negative ",
+                      "or NA values"))
     TRUE
 }
 
@@ -123,10 +166,10 @@ validate_dimnames_slot <- function(x, dim, slotname="dimnames")
 {
     x_dimnames <- slot(x, slotname)
     if (!is.list(x_dimnames))
-        return(wmsg2(sprintf("'%s' slot must be a list", slotname)))
+        return(paste0("'", slotname, "' slot must be a list"))
     if (length(x_dimnames) != length(dim))
-        return(wmsg2(sprintf("'%s' slot must have ", slotname),
-                     "one list element per dimension in the object"))
+        return(paste0("'", slotname, "' slot must have ",
+                      "one list element per dimension in the object"))
     ok <- vapply(seq_along(dim),
                  function(along) {
                    dn <- x_dimnames[[along]]
@@ -137,9 +180,9 @@ validate_dimnames_slot <- function(x, dim, slotname="dimnames")
                  logical(1),
                  USE.NAMES=FALSE)
     if (!all(ok))
-        return(wmsg2(sprintf("each list element in '%s' slot ", slotname),
-                     "must be NULL or a character vector along ",
-                     "the corresponding dimension in the object"))
+        return(paste0("each list element in '", slotname, "' slot ",
+                      "must be NULL or a character vector along ",
+                      "the corresponding dimension in the object"))
     TRUE
 }
 
@@ -219,8 +262,8 @@ get_rev_index <- function(part_index)
 ### set_user_option() / get_user_option()
 ###
 
-### --- DISABLED CODE ---
-if (FALSE) {
+if (FALSE) {  # ------------ BEGIN DISABLED CODE ------------
+
 ### In the context of BiocParallel::bplapply() and family, we want the workers
 ### to inherit the user-controlled options defined on the master. Workers can
 ### also modify the inherited options or define new user-controlled options
@@ -355,8 +398,7 @@ get_user_option <- function(name)
         stop(wmsg("Unkown DelayedArray user-controlled global option: ", name))
     user_options[[idx]]
 }
-}
-### --- END OF DISABLED CODE ---
+}             # ------------- END DISABLED CODE -------------
 
 set_user_option <- function(name, value)
 {
